import { Extension } from '@codemirror/state';
import { TagStyle } from '@codemirror/language';
export interface CreateThemeOptions {
    /**
     * Theme inheritance. Determines which styles CodeMirror will apply by default.
     */
    dark: Theme;
    /**
     * Settings to customize the look of the editor, like background, gutter, selection and others.
     */
    settings: Settings;
    /** Syntax highlighting styles. */
    styles: TagStyle[];
}
declare type Theme = 'light' | 'dark';
export interface Settings {
    /** Editor background. */
    background: string;
    /** Default text color. */
    foreground: string;
    /** Caret color. */
    caret: string;
    /** Selection background. */
    selection: string;
    /** Background of highlighted lines. */
    lineHighlight: string;
    /** Gutter background. */
    gutterBackground: string;
    /** Text color inside gutter. */
    gutterForeground: string;
}
export declare const createTheme: ({ dark, settings, styles }: CreateThemeOptions) => Extension;
export default createTheme;
